==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/lsfunctions/TRIPTimer.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */
static const char* const TRIPTimer_cxx_Version = 
"$Id: TRIPTimer.cxx,v 1.5 2000/11/08 03:19:49 kevin Exp $";
#include <stdio.h>

#include "TRIPTimer.hxx"
#include "TRIPTimerEvent.hxx"
#include "Event.hxx"
#include "cpLog.h"
#include "TRIPTimerAgent.hxx"

Sptr < Fifo < Sptr < Event > > > TRIPTimer::_timerFifo = 0;
Sptr<VThread>  TRIPTimer::_thread = 0;

TRIPTimer::TRIPTimer() : _eventId(0)
{
    if (_timerFifo == 0)
    {
	_timerFifo = new Fifo < Sptr < Event > > ;
    }
    if (_thread == 0)
    {
	_thread = new VThread();
	_thread->spawn(TRIPTimer::run, this);
    }
}


void*
TRIPTimer::run(void* args)
{
    //TRIPTimer* self = static_cast < TRIPTimer* > (args);

    // Need code to read from Fifo for new events
    while (true)
    {
	assert( _timerFifo != 0 );
	Sptr < Event > nextEvent = _timerFifo->getNext();
	assert( nextEvent != 0 );
	
	Sptr < TRIPTimerEvent > tripTimerEvent;
	tripTimerEvent.dynamicCast(nextEvent);
	if (tripTimerEvent != 0)
	{
	    tripTimerEvent->process();
	}
    }
    return (NULL);
}

void
TRIPTimer::startTimer(TRIPTimerAgent& agent,  const int timerMs )
{
    assert( _timerFifo != 0 );
    if (_eventId != 0)
    {
	_timerFifo->cancel(_eventId);
    }
    Sptr <TRIPTimerEvent> newEvent = new TRIPTimerEvent(agent);
    _eventId = _timerFifo->addDelayMs( newEvent, timerMs );
}

void
TRIPTimer::cancelTimer()
{
    cpLog(LOG_DEBUG, "TRIPTimer::cancelTimer");
    assert( _timerFifo != 0 );
    if (_eventId != 0)
    {
        _timerFifo->cancel( _eventId );
	_eventId = 0;
    }
}

void
TRIPTimer::clearTimerId()
{
    _eventId = 0;
}

FifoEventId
TRIPTimer::getTimerId()
{
    return ( _eventId );
}

Sptr < Fifo < Sptr < Event > > >
TRIPTimer::getFifo( ) const
{
    return _timerFifo;
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/lsfunctions/TRIPTimer.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */
static const char* const TRIPTimer_cxx_Version = 
"$Id: TRIPTimer.cxx,v 1.12 2001/03/07 23:58:23 kevinmc Exp $";
#include <stdio.h>

#include "TRIPTimer.hxx"
#include "TRIPTimerEvent.hxx"
#include "cpLog.h"
#include "TRIPTimerAgent.hxx"

Sptr < Fifo < Sptr < TRIPTimerEvent > > > TRIPTimer::_timerFifo = 0;
Sptr<VThread>  TRIPTimer::_thread = 0;
int TRIPTimer::count = 0;
bool TRIPTimer::_waiting = false;
bool TRIPTimer::_shutdown = false;

TRIPTimer::TRIPTimer() : _eventId(0)
{
    if (_timerFifo == 0)
    {
        _timerFifo = new Fifo < Sptr < TRIPTimerEvent > > ;
    }
    if (_thread == 0)
    {
        _thread = new VThread();
        _thread->spawn(TRIPTimer::run, this);
    }
    count++;
}

TRIPTimer::~TRIPTimer()
{
    count--;
    if (count == 0)
    {
        if ((_timerFifo.getPtr()) && _waiting)
        {
            _shutdown = true;
            _timerFifo->add(0);
        }
        if (_thread.getPtr())
        {
            _thread->join();
            _thread->exit();
        }
        if (_timerFifo.getPtr())
        {
            _timerFifo = 0;
        }
    }
}


void*
TRIPTimer::run(void* args)
{
    //TRIPTimer* self = static_cast < TRIPTimer* > (args);

    // Need code to read from Fifo for new events
    while (true)
    {
        assert( _timerFifo.getPtr());
        _waiting = true;
        Sptr < TRIPTimerEvent > nextEvent = _timerFifo->getNext();
        _waiting = false;
        if (_shutdown) break;
        assert( nextEvent.getPtr() );
        nextEvent->process();
    }
    return (NULL);
}

void
TRIPTimer::startTimer(TRIPTimerAgent& agent,  const int timerMs )
{
    assert( _timerFifo.getPtr());
    if (_eventId != 0)
    {
        _timerFifo->cancel(_eventId);
    }
    Sptr <TRIPTimerEvent> newEvent = new TRIPTimerEvent(agent);
    _eventId = _timerFifo->addDelayMs( newEvent, timerMs );
}

void
TRIPTimer::cancelTimer()
{
    assert( _timerFifo.getPtr() );
    if (_eventId != 0)
    {
        _timerFifo->cancel( _eventId );
        _eventId = 0;
    }
}

void
TRIPTimer::clearTimerId()
{
    _eventId = 0;
}

FifoEventId
TRIPTimer::getTimerId()
{
    return ( _eventId );
}

Sptr < Fifo < Sptr < TRIPTimerEvent > > >
TRIPTimer::getFifo( ) const
{
    return _timerFifo;
}
